-------------------------------------------------------------------------------
-- Name: class Capabilities
-- Author: Jonathan Primeau
--
-- Description:
--     This class is handling the capabilities. The application uses this class
--     to know if it has access to specific area.
--
------------------------------------------------------------------------------- 

-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------

property ancestor              -- Parent
property pRules

-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = void
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end


on Try (me, theFunction)
  
  lCurrLogin = QI(#status).GetStatus().login
  
  lRuleCount = me.pRules.count
  repeat with i = 1 to lRuleCount
    if (me.pRules[i].function = theFunction or me.pRules[i].function = "all") then
      if (me.pRules[i].login = lCurrLogin or me.pRules[i].login = "all") then
        return(me.pRules[i].response)
      end if
    end if
  end repeat
  
  return(false)
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pRules = []
  
  -- Most restrictive rule
  
  -- home
  me._AddRules("none", "home", false)
  me._AddRules("TSC", "home", true)
  me._AddRules("Tryout", "home", true)
  
  -- video
  me._AddRules("none", "video", false)
  me._AddRules("TSC", "video", true)
  me._AddRules("Tryout", "video", true)
  
  -- handicapping
  me._AddRules("none", "handicapping", false)
  me._AddRules("TSC", "handicapping", true)
  me._AddRules("Tryout", "handicapping", false)
  
  -- account
  me._AddRules("none", "account", false)
  me._AddRules("TSC", "account", true)
  me._AddRules("Tryout", "account", false)
  
  -- internet
  me._AddRules("none", "internet", false)
  me._AddRules("TSC", "internet", true)
  me._AddRules("Tryout", "internet", false)
  
  -- services
  me._AddRules("none", "services", false)
  me._AddRules("TSC", "services", true)
  me._AddRules("Tryout", "services", true)
  
  -- wagering
  me._AddRules("none", "wagering", false)
  me._AddRules("TSC", "wagering", true)
  me._AddRules("Tryout", "wagering", false)
  
  -- logout
  me._AddRules("none", "logout", false)
  me._AddRules("TSC", "logout", true)
  me._AddRules("Tryout", "logout", true)
  
  -- Less restrictive rule
  me._AddRules("all", "all", true)
end

on _AddRules (me, theLogin, theFunction, theResponse)
  lCurrentRule = [:]
  lCurrentRule.addProp(#login, theLogin)
  lCurrentRule.addProp(#function, theFunction)
  lCurrentRule.addProp(#response, theResponse)
  me.pRules.add(lCurrentRule)
end