-------------------------------------------------------------------------------
-- Name: class Command
-- Author: Jonathan Primeau
--
-- Description:
--     This class is used to build and parse commands.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------

property ancestor              -- Parent
property pCommandIndex
property pCommand
property pAttributeCount
property pEOL                  -- End of line
property pEOC                  -- End of command


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = void
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on BeginCommand (me)
  me.pCommand = ""
  me.pAttributeCount = 0
end

on SetOperation (me, theOperation)
  me.pCommand = theOperation
end

on SetCodeStatus (me, theCode, theStatus)
  me.pCommand = theCode && theStatus
end

on AddAttribute (me, theAttribute, theValue)
  lSep = me._GetSeparator()
  lAttribute = lSep & theAttribute & ":" && theValue
  me.pCommand = me.pCommand & lAttribute
  me.pAttributeCount = me.pAttributeCount + 1
end

on EndControl (me)
  me.pCommand = me.pCommand & me.pEOL
end

on SetData (me, theData)
  me.pCommand = me.pCommand & theData
end

on EndCommand (me)
  me.pCommand = me.pCommand & me.pEOL & me.pEOC
end

on Get (me)
  return(me.pCommand)
end

on GetDataLength (me, theData)
  lData = string(theData)
  lLength = lData.char.count + 2 -- CR
  return(lLength)
end

on GetID (me)
  lName = QI(#status).GetKioskName()
  lTime = baSystemTime("%0H%0M%0S")
  lIndex = me._GetCommandIndex()
  lID = lName & "-" & lTime & "-" & lIndex
  return(lID)
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pCommandIndex = 1
  me.pAttributeCount = 0
  me.pEOL = GetCommandCR()
  me.pEOC = GetCommandDelimiter()
end

on _GetCommandIndex (me)
  lCurrent = me.pCommandIndex
  me.pCommandIndex = me.pCommandIndex + 1
  return(lCurrent)
end

on _GetSeparator (me)
  if (me.pAttributeCount > 0) then
    return(", ")
    --return(" ")
  else
    return(" ")
  end if
end 