-------------------------------------------------------------------------------
-- Name: class Communicator
-- Author: Jonathan Primeau
--
-- Description:
--     This class is a layer between the application objects and the
--     communication with servers. It is meant to be a simple interface
--     to get data from a server. It allows other scripts to focus on
--     their real duties.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
-------------------------------------------------------------------------------

property ancestor              -- Parent
property pCallback             -- Current callback to be called

-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = void
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
  
  QI(#server2).BreakConnection()
end

on GetBanner (me, theHandler, theObject)
  me.pCallback.handler = theHandler
  me.pCallback.object = theObject
  
  QI(#server).SetCallback(#_GetBannerContentCallback, me)
  
  QI(#server).Connect("GetBanner")
end

on InitializeKiosk (me, theHandler, theObject)
  me.pCallback.handler = theHandler
  me.pCallback.object = theObject
  
  QI(#server2).SetCallback(#_InitializeKioskCallback, me)
  QI(#server2).SendCommand("InitializeKiosk id: iwp, ip: 205.236.16.42, kiosk: iwp, port: 51002")
end

-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pCallback = [#handler: void, #object: void]
  
  QI(#server2).SetIP("205.236.16.42")
  QI(#server2).SetPort(50001)
  
  QI(#server2).Connect()
end

on _GetBannerContentCallback (me, theStatus, theContent)
  QI(#server).BreakConnection()
  
  -- Call the specified callback to return the content of the request
  call(me.pCallback.handler, me.pCallback.object, theContent)
end

on _InitializeKioskCallback (me, theStatus, theContent)
  -- Call the specified callback to return the content of the request
  --call(me.pCallback.handler, me.pCallback.object, theContent)
end