-------------------------------------------------------------------------------
-- Name: class Handicapping
-- Author: Jonathan Primeau
--
-- Description:
--     This class takes care of the handicapping section. It creates the screen
--     dynamically according to the skin.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class DynamicScreen").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Load (me)
  GenLog(#debug, "Handicapping::Load: Loading handicapping...")
  -- Get the list of buttons from the skin manager
  me.pMainButtons = QI(#skin).GetHandicappingMainButtons()
  me.pSubButtons = QI(#skin).GetHandicappingSubButtons()
  
  ancestor.Load()
  GenLog(#debug, "Handicapping::Load: Handicapping loaded!")
end

on Clear (me)
  ancestor.Clear()
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  ancestor._Init()
  
  me.pMaxMainButton = 3
  me.pItemPerPage = 9
  
  me.pMainSpritePrefix = "handicapping,main,"
  me.pSubSpritePrefix = "handicapping,sub,"
end

