-------------------------------------------------------------------------------
-- Name: class LoginTimeout
-- Author: Jonathan Primeau
--
-- Description:
--     Takes care of the login timeout. The login timeout is the one that
--     triggers the logout timeout, the screen where there is a countdown 
--     before the user gets automatically logout.
--
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- P R O P E R T I E S
------------------------------------------------------------------------------- 

property ancestor              -- Parent
property pLastMouseLoc
property pCheckEvent


-------------------------------------------------------------------------------
-- P U B L I C  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- me new (me)
--
-- This the constructor. It creates the ancestor object (if any) and calls
-- _Init to intialize stuff.
--
-- Parameters:
--     me (object): this pointer.
--
-- Return:
--     me (object): A new instance of this class.
--
-------------------------------------------------------------------------------
on new (me)
  me.ancestor = script("class Timeout").new()
  
  -- Initialize
  me._Init()
  
  return(me)
end

-------------------------------------------------------------------------------
-- void Destroy (me)
--
-- This the destructor. It clears everything and also destroys the ancestor
-- (if any.)
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on Destroy (me)
  if (objectP(me.ancestor)) then
    me.ancestor.Destroy()
  end if
  me.ancestor = void
end

on Start (me)
  GenLog(#debug, "LoginTimeout::Start: Starting timer...")
  
  me.ResetHit()
  me.SetName("to,login")
  me.SetHitScale(1000) -- 1 second
  
  lTimeout = integer(QI(#config).GetLoginTimeout())
  me.SetTimeout(lTimeout)
  
  me.SetHitCallback(#_HitCallback, me)
  me.SetTimeoutCallback(#_TimeoutCallback, me)
  
  if (ancestor.Start() = true) then
    me.pCheckEvent = true
    QI(#events).RegisterListener(#onPulse, #_OnPulse, me)
    QI(#events).RegisterListener(#onEnterbetActivity, #_OnEnterbetActivity, me)
    GenLog(#debug, "LogoutTimeout::Start: Timer started!")
  else 
    GenLog(#error, "LogoutTimeout::Start: Timer NOT started!")
  end if
end

on Stop (me)
  GenLog(#debug, "LoginTimeout::Stop: Stopping timer...")
  me.pCheckEvent = false
  QI(#events).UnregisterListener(#onPulse, #_OnPulse, me)
  ancestor.Stop()
  GenLog(#debug, "LoginTimeout::Stop: Timer stopped!")
end


-------------------------------------------------------------------------------
-- P R I V A T E  M E T H O D S
-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- void _Init (me)
--
-- Initializes private properties. This is called by the constructor (new).
--
-- Parameters:
--     me (object): this pointer.
--
-------------------------------------------------------------------------------
on _Init (me)
  me.pLastMouseLoc = point(0, 0)
  me.pCheckEvent = false
end

on _HitCallback (me)
  
end

on _TimeoutCallback (me)
  QI(#ebLogin).Hide()
  QI(#login).GoToAttractLoop()
end

on _OnPulse (me)
  if (me.pCheckEvent = true) then
    lMouseLoc = _mouse.mouseLoc
    
    -- Reset hit if the mouse location moved
    if (lMouseLoc <> me.pLastMouseLoc) then
      me.ResetHit()
    end if
    
    -- Keep the current mouse location
    me.pLastMouseLoc = lMouseLoc
  end if
end

on _OnEnterbetActivity (me)
  GenLog(#debug, "ApplicationTimeout::EnterbetActivity:")
  me.ResetHit()
end